clear
clear matrix 
set more off
cd "C:\Users\padams3\Downloads\savings"
cap log close
log using AHPZ-Disclosure.log, replace

*-- Summary of code for AHPZ JFE "Testing the Effectiveness of Consumer Financial Disclosure: Experimental Evidence from Savings Accounts" paper -------------------------------------
* Questions? Contact Paul Adams <paulduncanadams@gmail.com>
                
/* TRIAL ARMS:
Trial 1 = Reverse Page Switching Box (referred to as Trial 2 in the paper)
Trial 2 = Front Page Switching Box (referred to as Trial 1 in the paper)
Trial 3 = SMS reminder (non random assignment) (referred to as Trial 5 in the paper)
Trial 4 = Digital reminder (SMS or Email) (referred to as Trial 4 in the paper)
Trial 5 = Return Switching Form (referred to as Trial 3 in the paper)

TABLES INCLUDED:
Table 2 = summary statistics by trial
Table 3 = Balance tests Control vs Treatment by trial
Table 4 = Treatment effects
Table 5 = Disclousure Design Effects
Table 6 = Disclosure Effectiveness by Consumer Heterogeneity
Table 7 = Effects of timing for Trial 3 and Trial 4 */              

*-------------------------------------------- DEALING WITH ACCOUNT BALANCES --------------------------------------------------------------

clear
use raw_data

count if poundsint>poundsext // 2 individuals that we see at 6 points in time
count if startbalance<0 // 2 individuals

* 2 people have negative starting balances, and this feeds through to poundsint>poundsext
* correct this to make poundsint=0 for these people

replace poundsint=0 if poundsint<0
replace poundsext=0 if poundsext<0

* Then can use poundsext as gains to be made
* create gains^2

gen gainssq=poundsext*poundsext
rename poundsext gains

save journaltemp, replace

*------------------------------------------- TABLES 2 AND 3: SUMMARY STATS AND BALANCE TESTS --------------------------------------------
                
* remove any missing values for key covariates
* trial 5 has no information on mobile/online logins, so have to run the cleaning seperately on trials 1-4 and trial 5
                
drop if trial==5
		
local varlist age gender pca_countdum startbalance accountage products onlinelogin mobilelogin
foreach v of local varlist {
	drop if `v'==.
	}

save temp, replace
clear all
use journaltemp

drop if trial!=5

local varlist age gender pca_countdum startbalance accountage products
foreach v of local varlist {
	drop if `v'==.
	}

append using temp

save master_data, replace

/* A NOTE ON TIMING IN TRIAL 4:

In Trial 4 (Digital Reminder SMS/Email), the intervention (email or SMS) was sent on the same day for everyone in the trial. Variation in timings come from
the timing of that email or SMS relative to when that particular account will experience a rate change (1 year after account opening). For comparability we 
also want to look at results for all trials 4 weeks after intervention. In the case of Trial 4 that means that we exclude people in the trial who have not
recieved treatment yet, above daydistrange>10. It also means that for Trial 4 we look at all the individuals who we have in our sample at week 4 to calculate 
the summary statistics (note that only account age varies (linearly) with time, so we do not beliefe this introduces any bias for our balance tests or summary 
stats). These are noted below. */
 

drop if trial==4&daydistrange>10 // Exclude individuals in the data who have not been treated yet at week 4
                       
 
*---------------TABLE 2: summarise variables by trial:
sum age gender pca_countdum startbalance gains accountage products onlinelogin mobilelogin if week==0 & trial==2
sum age gender pca_countdum startbalance gains accountage products onlinelogin mobilelogin if week==0 & trial==1
sum age gender pca_countdum startbalance gains accountage products if week==0 & trial==5
sum age gender pca_countdum startbalance gains accountage products onlinelogin mobilelogin if week==4 & trial==4
sum age gender pca_countdum startbalance gains accountage products onlinelogin mobilelogin if week==0 & trial==3

*trial 1 n= 13,261 labelled in paper as trial #2
*trial 2 n= 61,879 labelled in paper as trial #1
*trial 3 n= 30,202 labelled in paper as trial #5
*trial 4 n= 15,487 labelled in paper as trial #4
*trial 5 n= 4,003  labelled in paper as trial #3
                                
*---------------TABLE 3: Means of demographic variables and tests of equality of means*
*NOTE: Following Table 3 in the paper and reporting control vs any treatment, rather than the actual treatment groups*

*Means by control vs treatment*

bys treatmentdum: sum age gender pca_countdum startbalance accountage if week==0 & trial==2
bys treatmentdum: sum age gender pca_countdum startbalance accountage if week==0 & trial==1
bys treatmentdum: sum age gender pca_countdum startbalance accountage if week==0 & trial==5
bys treatmentdum: sum age gender pca_countdum startbalance accountage if week==4 & trial==4
bys treatmentdum: sum age gender pca_countdum startbalance accountage if week==0 & trial==3

*test means of individual variables by trial

*Trial 2 (Front Page Switching Box)
mvtest means age if week==0 & trial==2, by (treatmentdum)
mvtest means gender if week==0 & trial==2, by (treatmentdum)
mvtest means pca_countdum if week==0 & trial==2, by (treatmentdum)
mvtest means startbalance if week==0 & trial==2, by (treatmentdum)
mvtest means accountage if week==0 & trial==2, by (treatmentdum)
*joint test*
mvtest means age gender pca_countdum startbalance accountage if week==0 & trial==2, by (treatmentdum)

*Trial 1 (Reverse Page Switching box)
mvtest means age if week==0 & trial==1, by (treatmentdum)
mvtest means gender if week==0 & trial==1, by (treatmentdum)
mvtest means pca_countdum if week==0 & trial==1, by (treatmentdum)
mvtest means startbalance if week==0 & trial==1, by (treatmentdum)
mvtest means accountage if week==0 & trial==1, by (treatmentdum)
*joint test*
mvtest means age gender pca_countdum startbalance accountage if week==0 & trial==1, by (treatmentdum)

*Trial 5 (Switching Form)*

mvtest means age if week==0 & trial==5, by (treatmentdum)
mvtest means gender if week==0 & trial==5, by (treatmentdum)
mvtest means pca_countdum if week==0 & trial==5, by (treatmentdum)
mvtest means startbalance if week==0 & trial==5, by (treatmentdum)
mvtest means accountage if week==0 & trial==5, by (treatmentdum)
*joint test*
mvtest means age gender pca_countdum startbalance accountage if week==0 & trial==5, by (treatmentdum)

*Trial 4 (Digital Reminder)
mvtest means age if week==4 & trial==4, by (treatmentdum)
mvtest means gender if week==4 & trial==4, by (treatmentdum)
mvtest means pca_countdum if week==4 & trial==4, by (treatmentdum)
mvtest means startbalance if week==4 & trial==4, by (treatmentdum)
mvtest means accountage if week==4 & trial==4, by (treatmentdum)
*joint test*
mvtest means age gender pca_countdum startbalance accountage if week==4 & trial==4, by (treatmentdum)

*Trial 3 (SMS Reminder)
mvtest means age if week==0 & trial==3, by (treatmentdum)
mvtest means gender if week==0 & trial==3, by (treatmentdum)
mvtest means pca_countdum if week==0 & trial==3, by (treatmentdum)
mvtest means startbalance if week==0 & trial==3, by (treatmentdum)
mvtest means accountage if week==0 & trial==3, by (treatmentdum)
*joint test*
mvtest means age gender pca_countdum startbalance accountage if week==0 & trial==3, by (treatmentdum)

		
						
*--------------------------TABLE 4: INDIVIDUAL REGRESSIONS OF TREATMENTS ON ANY SWITCHING/INTERNAL SWITCHING --------------------------------------------        

*Internal and other switching

*Average Total Switching effect for pooled treatments

reg action treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==1, robust
reg action treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==2, robust
reg action treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==3, robust
reg action treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==4, robust
reg action treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==5, robust

* Average Internal Switching effect for pooled treatments

reg switchedwithin treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==1, robust
reg switchedwithin treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==2, robust
reg switchedwithin treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==3, robust
reg switchedwithin treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==4, robust
reg switchedwithin treatmentdum age agesq  gains gainssq gender pca_countdum if week==4&trial==5, robust

*-------------------------------------------POOLED REGRESSIONS OF TREATMENT ----------------------------------------------------------------

reg action treatmentdum age agesq gains gainssq gender pca_countdum if week==4, robust 
reg switchedwithin treatmentdum age agesq gains gainssq gender pca_countdum if week==4, robust 

*--------------------------TABLE 5: INDIVIDUAL REGRESSIONS OF TREATMENTS ON ANY SWITCHING/INTERNAL SWITCHING --------------------------------------------        

reg action i.group age agesq  gains gainssq gender pca_countdum if week==4&trial==1, robust
test 1.group=2.group=3.group=4.group
reg switchedwithin i.group age agesq  gains gainssq gender pca_countdum if week==4&trial==1, robust 
test 1.group=2.group=3.group=4.group

reg action i.group age agesq  gains gainssq gender pca_countdum if week==4&trial==2, robust 
test 1.group=2.group=3.group=4.group
reg switchedwithin i.group age agesq  gains gainssq gender pca_countdum if week==4&trial==2, robust 
test 1.group=2.group=3.group=4.group

reg action i.group age agesq  gains gainssq gender pca_countdum if week==4&trial==4, robust 
test 1.group=2.group
reg switchedwithin i.group age agesq  gains gainssq gender pca_countdum if week==4&trial==4, robust 
test 1.group=2.group


*----------------------------TABLE 6: HETEROGENEITY---------------------------------------------------------------------------------------

*reminder on age categories*

* agecateg = 0 if age<=40
* agecateg = 1 if age>40&age<=60
* agecateg = 2 if age>60&age<=80
* agecateg = 3 if age>80
* agecateg = . if age==.        

tab  agecateg

*reminder on internal gains categories*

* poundsintcateg=1 if poundsint<=50
* poundsintcateg=2 if poundsint>50&poundsint<=100
* poundsintcateg=3 if poundsint>100&poundsint<=500
* poundsintcateg=4 if poundsint>500
* poundsintcateg=. if poundsint==.

tab poundsintcateg

* reminder on external gains categories*

* poundsextcateg=1 if poundsext<=50
* poundsextcateg=2 if poundsext>50&poundsext<=100
* poundsextcateg=3 if poundsext>100&poundsext<=500
* poundsextcateg=4 if poundsext>500
* poundsextcateg=. if poundsext==.

/* reminder on accountagecategories

gen accountagecateg = 5 if opendate<td(01feb2006)
replace accountagecateg = 4 if opendate>=td(01feb2006)
replace accountagecateg = 3 if opendate>=td(01feb2011)
replace accountagecateg = 2 if opendate>=td(01feb2014)
replace accountagecateg = 1 if opendate>=td(01feb2015)
label define accountagetiers 1 "<1 year" 2 "1-2 years"  3 "2-5 years" 4 "5-10 years" 5 ">10 years" */

tab poundsextcateg

*Regressions on all switching with external gains categories, age categories and PCA dummy*
						
reg action treatmentdum##i.poundsextcateg treatmentdum##i.agecateg treatmentdum##pca_countdum if week==4&trial==1, robust
test 1.treatmentdum#1.poundsextcateg=1.treatmentdum#2.poundsextcateg=1.treatmentdum#3.poundsextcateg=1.treatmentdum#4.poundsextcateg=1.treatmentdum#1.agecateg=1.treatmentdum#2.agecateg=1.treatmentdum#3.agecateg=1.treatmentdum#1.pca_countdum

reg action treatmentdum##i.poundsextcateg treatmentdum##i.agecateg treatmentdum##pca_countdum if week==4&trial==2, robust
test 1.treatmentdum#1.poundsextcateg=1.treatmentdum#2.poundsextcateg=1.treatmentdum#3.poundsextcateg=1.treatmentdum#4.poundsextcateg=1.treatmentdum#1.agecateg=1.treatmentdum#2.agecateg=1.treatmentdum#3.agecateg=1.treatmentdum#1.pca_countdum

reg action treatmentdum##i.poundsextcateg treatmentdum##i.agecateg treatmentdum##pca_countdum if week==4&trial==3, robust
test 1.treatmentdum#1.poundsextcateg=1.treatmentdum#2.poundsextcateg=1.treatmentdum#3.poundsextcateg=1.treatmentdum#4.poundsextcateg=1.treatmentdum#1.agecateg=1.treatmentdum#2.agecateg=1.treatmentdum#3.agecateg=1.treatmentdum#1.pca_countdum

reg action treatmentdum##i.poundsextcateg treatmentdum##i.agecateg treatmentdum##pca_countdum if week==4&trial==4, robust
test 1.treatmentdum#1.poundsextcateg=1.treatmentdum#2.poundsextcateg=1.treatmentdum#3.poundsextcateg=1.treatmentdum#4.poundsextcateg=1.treatmentdum#1.agecateg=1.treatmentdum#2.agecateg=1.treatmentdum#3.agecateg=1.treatmentdum#1.pca_countdum

reg action treatmentdum##i.poundsextcateg treatmentdum##i.agecateg treatmentdum##pca_countdum if week==4&trial==5, robust
test 1.treatmentdum#1.poundsextcateg=1.treatmentdum#2.poundsextcateg=1.treatmentdum#3.poundsextcateg=1.treatmentdum#4.poundsextcateg=1.treatmentdum#1.agecateg=1.treatmentdum#2.agecateg=1.treatmentdum#3.agecateg=1.treatmentdum#1.pca_countdum



*----------------------------TABLE 7: REGRESSIONS ON TIMING OF TREATMENT FOR SMS AND DIGITAL REMINDER TRIALS --------------------------------

*TRIAL 3 - SMS TRIAL*
replace treatment=0 if group==0&trial==3 
replace treatment=1 if group==1&trial==3
replace treatment=3 if group==4&trial==3
replace treatment=2 if group==2&trial==3
replace treatment=2 if group==3&trial==3

*TRIAL 3/OPTION 1 - no controls for account age or fixed effects

reg action i.treatment age agesq gains gainssq gender pca_countdum if week==4&trial==3, robust
		
*treatment 0 = control
*treatment 1 = before deadline
*treatment 2 = on the day (both treatments combined)
*treatment 3 = after deadline

*TRIAL 3/OPTION 2 - fixed effects on opendate

xtset opendate
xtreg action i.treatment age agesq gains gainssq gender pca_countdum if week==4&trial==3, fe


*TRIAL 4 - DIGITAL REMINDER TRIAL*

*cohort 1 = 4 weeks before
*cohort 2 = 4-2 weeks before
*cohort 3 = 2-0 weeks before
*cohort 4 = 0-2 weeks after
*cohort 5 = 2-4 weeks after

*timing regression without cohort dummies*

reg action c.treatmentdum#cohort age agesq gains gainssq gender pca_countdum if week==4&trial==4, robust

* with cohort dummies (cohort is half-month cohort)

reg action treatmentdum#cohort i.cohort age agesq gains gainssq gender pca_countdum if week==4&trial==4, robust

log close
